.. _envsettings_reference:

Environment Settings Reference
==============================

This document lists all settings that can be set per environment. These changes are made through the API, the dashboard or the
CLI tool.

The supported settings are:

.. show-environment-settings::

